"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from livepeer_ai.types import BaseModel
from typing_extensions import TypedDict


class LLMResponseTypedDict(TypedDict):
    response: str
    tokens_used: int


class LLMResponse(BaseModel):
    response: str

    tokens_used: int
