"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from livepeer_ai.types import BaseModel
from typing_extensions import TypedDict


class ImageToTextResponseTypedDict(TypedDict):
    r"""Response model for text generation."""

    text: str
    r"""The generated text."""


class ImageToTextResponse(BaseModel):
    r"""Response model for text generation."""

    text: str
    r"""The generated text."""
