"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .chunk import Chunk, ChunkTypedDict
from livepeer_ai.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class TextResponseTypedDict(TypedDict):
    r"""Response model for text generation."""

    text: str
    r"""The generated text."""
    chunks: List[ChunkTypedDict]
    r"""The generated text chunks."""


class TextResponse(BaseModel):
    r"""Response model for text generation."""

    text: str
    r"""The generated text."""

    chunks: List[Chunk]
    r"""The generated text chunks."""
