"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from livepeer_ai.types import BaseModel
from typing_extensions import TypedDict


class MasksResponseTypedDict(TypedDict):
    r"""Response model for object segmentation."""

    masks: str
    r"""The generated masks."""
    scores: str
    r"""The model's confidence scores for each generated mask."""
    logits: str
    r"""The raw, unnormalized predictions (logits) for the masks."""


class MasksResponse(BaseModel):
    r"""Response model for object segmentation."""

    masks: str
    r"""The generated masks."""

    scores: str
    r"""The model's confidence scores for each generated mask."""

    logits: str
    r"""The raw, unnormalized predictions (logits) for the masks."""
