"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from livepeer_ai.models.components import (
    httpmetadata as components_httpmetadata,
    imageresponse as components_imageresponse,
)
from livepeer_ai.types import BaseModel
import pydantic
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class GenUpscaleResponseTypedDict(TypedDict):
    http_meta: components_httpmetadata.HTTPMetadataTypedDict
    image_response: NotRequired[components_imageresponse.ImageResponseTypedDict]
    r"""Successful Response"""


class GenUpscaleResponse(BaseModel):
    http_meta: Annotated[
        Optional[components_httpmetadata.HTTPMetadata], pydantic.Field(exclude=True)
    ] = None

    image_response: Optional[components_imageresponse.ImageResponse] = None
    r"""Successful Response"""
