"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from livepeer_ai.types import BaseModel
from typing import Any, List
from typing_extensions import TypedDict


class ChunkTypedDict(TypedDict):
    r"""A chunk of text with a timestamp."""

    timestamp: List[Any]
    r"""The timestamp of the chunk."""
    text: str
    r"""The text of the chunk."""


class Chunk(BaseModel):
    r"""A chunk of text with a timestamp."""

    timestamp: List[Any]
    r"""The timestamp of the chunk."""

    text: str
    r"""The text of the chunk."""
